# PyCersi

![License](https://img.shields.io/badge/License-MIT-green.svg)
![Python Versions](https://img.shields.io/pypi/pyversions/pycersi)

##### DEVELOPED BY SUBHRA CHAKRABORTI

##### LAST UPDATE: 31ST AUGUST 2024

##### VERSION: 4.0.0

## Overview

PyCersi is a simple Python library that provides essential tools for number fuctions (described below).
It is easy to use, lightweight, and can be integrated into various Python projects.

## Features

PyCersi offers a collection of number-related utilities that can simplify common mathematical tasks:

- **Searchers**

  - `Fibonacci Upto Program : fiboupto`
  - `Fibonacci Range Program : fiborange`
  - `Floyd Triangle Program`
  - `Greatest Common Divisor Program`
  - `Least Common Multiple Program`

- **Number Property Checkers**

  - `Abundant Number Checker`
  - `Armstrong Number Checker`
  - `Automorphic Number Checker`
  - `Buzz Number Checker`
  - `Circular Prime Number Checker`
  - `Curzon Number Checker`
  - `Composite Number Checker`
  - `CoPrime Number Checker`
  - `Disarium Number Checker`
  - `Dudeney Number Checker`
  - `Duck Number Checker`
  - `Even Number Checker`
  - `Fibonacci Number Checker`
  - `Happy Number Checker`
  - `Harshad Number Checker`
  - `Heteromecic Number Checker`
  - `Krishnamurthy Number Checker`
  - `Magic Number Checker`
  - `Neon Number Checker`
  - `Niven Number Checker`
  - `Oblong Number Checker`
  - `Odd Number Checker`
  - `Palindrome Number Checker`
  - `Perfect Number Checker`
  - `Prime Number Checker`
  - `Pronic Number Checker`
  - `Sunny Number Checker`
  - `Special Number Checker`
  - `Spy Number Checker`
  - `Twin Prime Number Checker`
  - `Twisted Prime Checker`
  - `Unique Number Checker`
  - `Tech Number Checker`
  - `Ugly Number Checker`

- **Mathematical Functions**

  - `Area of Circle : ar_circle`
  - `Area of Rectangle : ar_rect`
  - `Area of Triangle : ar_triangle`
  - `Digit to Word Converter`
  - `Factorial Calculator`
  - `Factors Calculator`

- **Stack Functions**

  - `Push Into Stack : s_push`
  - `Pop Out Of Stack : s_push`
  - `Size Of Stack : s_size`
  - `Underflow Stack Checker : s_empty`
  - `Top Of Stack : s_top`
  - `Display Stack : s_display`

These functions are designed to help you perform common number-related operations efficiently and can be easily integrated into larger projects.

## Installation

PyCersi is available on PyPI and can be installed using `pip` on various platforms including Windows, macOS, and Linux.

### Windows

1. **Install Python**: Make sure Python is installed on your system. You can download it from the official [Python website](https://www.python.org/downloads/).
2. **Open Command Prompt**: Press `Win + R`, type `cmd`, and hit Enter.
3. **Run the pip command**:

```bash
pip install pycersi
```

### macOS

1. **Install Python**: Ensure Python is installed. You can use Homebrew to install it:

```bash
brew install python
```

2. **Open Terminal**: You can find Terminal in Applications > Utilities.

```bash
pip3 install pycersi
```

### Linux (Ubuntu/Debian-based)

1. **Update Packages**:

```bash
sudo apt update
```

2. **Install Python and pip**:

```bash
sudo apt install python3 python3-pip
```

3. **Run the pip command**:

```bash
pip3 install pycersi
```

## Using The Functions

1. For using any _searchers_ functions from PyCersi module, use:
   `pycersi.<name>(limit)`.

- Example: `pycersi.fibo(limit)`

2. For using any _checker_ functions from PyCersi module, use:
   `pycersi.is<name>(value)`.

- Example: `pycersi.issunny(value)`

3. For using any _mathematical_ function from PyCersi module, use:
   `pycersi.cal<name>(value)`.

- Example: `pycesi.calfact(value)`

4. For using any _stack_ function from PyCersi module, use:
   `pycersi.s_<name>(stack,[element])`.

- Example: `pycesi.s_top(book_stack)`

## Contributing

I welcome contributions to the project! If you want to contribute, please follow these steps:

Fork the repository.

1. Create a new branch (`git checkout -b feature-branch`).
2. Make your changes and commit them (`git commit -m 'Add some feature'`).
3. Push to the branch (`git push origin feature-branch`).
4. Create a pull request.
   Please make sure your code follows the project's coding standards and includes tests.

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/subhrachakraborti/PyCersi/blob/main/LICENSE) file for details.

## Contact

If you have any questions, feel free to open an issue or contact me directly at [mail@subhrachakraborti](mailto:mail@subhrachakraborti.com).

## Acknowledgments

- - Math Library
- - Python Org
- - Visual Studio Code
- - GitHub
- - Microsoft Corporation
